Crate elbey_cache

Crate elbey_cache 

Cache and shared app metadata types for the Elbey launcher.

This crate provides a sled-backed cache for desktop app metadata and icon data, along with the app descriptor types used by the launcher.

It uses iced types for images. Data is returned in order of exec_count. This value is updated each time an app is launched by the user.

Clients should call refresh() off the critical path to refresh the cache from Desktop apps on disk

Structs

AppDescriptor
App metadata stored in and loaded from the cache.
Cache
Tracks state to sort apps by usage and persist cached metadata.

Enums

IconHandle
UI-ready icon handle used by the launcher.

Constants

DEFAULT_ICON_SIZE
Default icon size for freedesktop icon lookups.

Statics

FALLBACK_ICON_HANDLE
SVG fallback icon when an app has no resolved icon.

Functions

clear_cache_dir
Remove the cache directory for the default namespace.