pub struct Cache { /* private fields */ }Expand description
Tracks state to sort apps by usage and persist cached metadata.
Implementations
Sourceimpl Cache
impl Cache
Sourcepub fn new(apps_loader: fn() -> Vec<AppDescriptor>) -> Self
pub fn new(apps_loader: fn() -> Vec<AppDescriptor>) -> Self
Create a cache using the default Elbey cache namespace.
pub fn is_empty(&self) -> bool
Sourcepub fn read_all(&mut self) -> Option<Vec<AppDescriptor>>
pub fn read_all(&mut self) -> Option<Vec<AppDescriptor>>
Load all cached entries into app descriptors, if available.
Sourcepub fn read_top(&mut self, count: usize) -> Option<Vec<AppDescriptor>>
pub fn read_top(&mut self, count: usize) -> Option<Vec<AppDescriptor>>
Load up to count cached entries into app descriptors, if available.
pub fn refresh(&mut self) -> Result<()>
Sourcepub fn load_from_apps_loader(&mut self) -> Vec<AppDescriptor>
pub fn load_from_apps_loader(&mut self) -> Vec<AppDescriptor>
Load from cache when present, falling back to the loader and populating icons.
Sourcepub fn update(&mut self, selected_app: &AppDescriptor) -> Result<()>
pub fn update(&mut self, selected_app: &AppDescriptor) -> Result<()>
Refresh from the loader and increment usage for the selected app.
Sourcepub fn store_snapshot(&mut self, apps: &[AppDescriptor]) -> Result<()>
pub fn store_snapshot(&mut self, apps: &[AppDescriptor]) -> Result<()>
Store a snapshot of apps, reusing cached icon data when possible.
pub fn build_snapshot_with_icons( &mut self, apps: &[AppDescriptor], ) -> Result<()>